function h= colorplot(x,y,freqs,COLOR, resize)
% this function plots X-Y scatter using dots of different size
% and color to differentiate data that appears more than once
% at one X,Y coordinate. 
% typical values:
% freqs = frequencies that are displayed by different size/color
% COLOR: color use to create a color gradient (green = [0 1 0] )
% resize: 0 do not resize the dots, 1 resize the dots
% typical usage:
% colorplot(X,Y,[1 3 10 30 100 300 1000],[0 1 0],2,1);


% if datasets are empty, quit the function
if isempty(x) || isempty(y)
    return
end
% this algorithm works only when values are >1
% if they are <1, they have to be scaled first

if min(x)<1
    scalex = 100*10^( -floor(log10(min(x))) );
    x = round(scalex*x);
else
    scalex=1;
end

if min(y)<1
    scaley = 100*10^( -floor(log10(min(y))) );
    y = round(scaley*y);
else
    scaley = 1;
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% in this section we count number of occurences of each coordinate

    MAX = max([max(x) max(y)]);
    COEF = 10^( ceil(log10(MAX))+1 );
    
    z = x*COEF + y;                % collapse two coordinates in one number
    z = sort(z);
    [sZ,M,~] = unique(z, 'first'); % finds unique z1
    M2 = [M(2:end); numel(z)+1];   % creates shifted index array M2
    Occur = M2-M;                  % find the number of occurences
    x1 = floor(sZ/COEF);           % transform back to xy-coordinates
    y1 = (sZ-x1*COEF);

        
    [Occur, IX ] = sort(Occur);    % sort occurences and coordinates
    maxOccur = max(Occur);
    x1=x1(IX);
    y1=y1(IX);

    IND(1) = 1;
    ii=1;
    for i=1:numel(freqs)           % find indeces for each frequency range
        ii=ii+1;
        if ~isempty( find(Occur>=freqs(i), 1  ) )
            IND(ii) = find( Occur>=freqs(i) , 1 ) ;
        else
            IND(ii) = NaN;
        end
    end
    clear ii;

    IND(numel(freqs)+1) = numel(Occur)+1;
    IND2 =  IND (~isnan(IND));
    FRA = 1/numel(freqs);

 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% in this section we plot each occurence separatelly

    for i = 1:numel(IND2)-1

        PLOT = IND2(i):IND2(i+1)-1;  % indeces of data to plot
        hold on;
        if resize
            SIZE = 1+i;
        else
            SIZE = 2;
        end

        h=plot(x1(PLOT)/scalex,y1(PLOT)/scaley,...
                        'o',...
                        'MarkerEdgeColor',(1-FRA*i)*COLOR,...
                        'MarkerFaceColor',(1-FRA*i)*COLOR,...
                        'MarkerSize',SIZE);  
    end
end